@@ -23,7 +23,7 @@
         if (missing(radius))
             radius <- max(apply(x, 2, function(z) diff(range(z))))/100
         ## users may expect cex to work (I would)
-        cex <- match.call(expand.dots = FALSE)$...$cex
+        cex <- eval(match.call(expand.dots = FALSE)$...$cex)
         if (!is.null(cex))
             radius <- cex * radius
         rgl.spheres(x, radius = radius, col = col,  ...)
@@ -46,6 +46,8 @@
         (is.list(object) && !is.null(object$CCA) && object$CCA$rank > 0)) {
         if (!missing(envfit)) 
             object <- envfit
+        if (!missing(envfit) && is.na(envfit))
+            return(invisible())
         bp <- scores(object, dis = "bp", choices = choices)
         cn <- scores(object, dis = "cn", choices = choices)
         if (!is.null(cn) && !any(is.na(cn))) {
